@@ -1,14 +1,15 @@
-# $Id: /mirror/coderepos/lang/perl/Catalyst-Model-Data-Localize/trunk/lib/Catalyst/Plugin/Data/Localize.pm 101680 2009-03-03T15:00:50.252097Z daisuke  $
+# $Id: Localize.pm 33133 2009-05-07 05:38:54Z daisuke $
 
 package Catalyst::Plugin::Data::Localize;
 use strict;
 use warnings;
 
 use Catalyst::Model::Data::Localize;
+use Class::C3::Adopt::NEXT;
 
 sub setup {
     my $self = shift;
-    $self->NEXT::setup(@_);
+    $self->next::method(@_);
 
     $self->mk_classdata($_) for qw(localize_model);
 
@@ -81,4 +82,4 @@ under the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
-=cut
\ No newline at end of file
+=cut
